import { defineConfig } from 'vite'
import { resolve } from 'path'
import handlebars from 'vite-plugin-handlebars'
import inputs from './vite.inputs.js'

const output = '../dist/'
const assets = ''
const isWatch = process.argv.includes('--watch')

// https://vitejs.dev/config/
export default defineConfig(({mode}) => ({
  base: './',
  root: './src',

  plugins: [

    handlebars({
      partialDirectory: resolve(__dirname, 'src/partials'),
      context: {
        title: 'Hello, world!',
      },
    })
  ],
  build: {
    minify: mode === 'development' || isWatch === true ? false : 'terser',
    emptyOutDir: true,
    outDir: output,
    sourcemap: false,
    cssCodeSplit: true,
    rollupOptions: {
      input: inputs,
      output: {
        chunkFileNames: `${assets}js/[name].min.js`,
        entryFileNames: `${assets}js/[name].min.js`, 
        assetFileNames: assetInfo => {
          const info = assetInfo.name.split('.')
          const extType = info[info.length - 1]
          if (/\.(png|jpe?g|gif|svg|webp|webm|mp3)$/.test(assetInfo.name)) {
            return `${assets}img/${extType}/[name].${extType}`
          }
          if (/\.(css)$/.test(assetInfo.name)) {
            return `${assets}css/[name].min.${extType}`
          }
          if (/\.(woff|woff2|eot|ttf|otf)$/.test(assetInfo.name)) {
            return `${assets}fonts/[name].min.${extType}`
          }
          return `[name].${extType}`
        },
      },
    }
  },
  server: {
    open: 'test.html',
    useFullPath: true
  },
}))